@@ -2,7 +2,8 @@
 import copy
 import sys,os
 from os import  path
-sys.path.append('../')
+sys.path.append(os.path.dirname(path.dirname(__file__)))
+sys.path.append(path.dirname(__file__))
 from commFunction import getip,log_time,global_result,sftp_connect,sftp_put,sftp_disconnect,get_file_path
 import shutil
 from  socketClient import SocketClient
