@@ -8,7 +8,7 @@ from .STI.cal_sti import cal_sti
 from .STOI.STOI import *
 from .resample.resampler import resample,restruct
 from .timeAligment.time_align import cal_fine_delay
-from .commFunction import get_data_array,get_file_path,get_rms
+from .commFunction import get_data_array,get_file_path,get_rms,convert_error_header
 from .PCC.Pearson_CC import cal_PCC,get_max_cc_by_dll
 from .Noise_Suppression.noiseFuction import cal_noise_Supp
 from .SNR_ESTIMATION.MATCH_SIG import match_sig
@@ -25,6 +25,7 @@ from .AEC_MOS.aecmos import cal_aec_mos
 from .MOS_INFER.run_predict import cal_mos_infer
 from .Noise_Suppression.noiseFuction import  cal_noise_Supp
 from .CLIPPING_DETECTION.audio_clip_detection import cal_clip_index
+from .AEC_EVALUATION.FR_ECHO_DETECT import cal_fullref_echo
 from operator import methodcaller
 from .computeAudioQuality.mainProcess import computeAudioQuality
 
@@ -36,7 +37,7 @@ def compute_audio_quality(metrics,testFile=None,refFile=None,micFile=None,cleFil
     """
     :param metrics: G160/P563/POLQA/PESQ/STOI/STI/PEAQ/SDR/SII/LOUDNESS/MUSIC/MATCH/
                     TRANSIENT/GAINTABLE/ATTACKRELEASE/MUSICSTA/AGCDELAY/MATCHAEC/
-                    ERLE/SLIENCE/FORMAT/AECMOS/AIMOS/TRMS/ARMS/NOISE/CLIP/DELAY，必选项
+                    ERLE/SLIENCE/FORMAT/AECMOS/AIMOS/TRMS/ARMS/NOISE/CLIP/DELAY/ECHO，必选项
     # G160 无采样率限制；  WAV/PCM输入 ；三端输入: clean、ref、test；无时间长度要求；
     # P563 8000hz(其他采样率会强制转换到8khz)；  WAV/PCM输入 ；单端输入: test；时长 < 20s；
     # POLQA 窄带模式  8k  超宽带模式 48k ；WAV/PCM输入 ；双端输入：ref、test；时长 < 20s；
@@ -63,6 +64,7 @@ def compute_audio_quality(metrics,testFile=None,refFile=None,micFile=None,cleFil
     # NOISE 无采样率限制 WAV/PCM输入 ；双端输入：ref、test；无时间长度要求；
     # CLIP 无采样率限制 WAV/PCM输入 ；单端输入：test；无时间长度要求；
     # DELAY 无采样率限制; WAV/PCM输入;双端输入：ref、test； 无时间长度要求；
+    # ECHO 无采样率限制; WAV/PCM输入;双端输入：ref、test； 无时间长度要求；
     不同指标输入有不同的采样率要求，如果传入的文件不符合该指标的要求，会自动变采样到合法的区间
     :param testFile: 被测文件，必选项
     :param refFile:  参考文件，可选项，全参考指标必选，比如POLQA/PESQ/PEAQ
